@@ -1,9 +1,10 @@
 import dataclasses
-import enum
 import json
 
 
 class BaseEvent:
+    def to_dict(self):
+        return json.loads(self.as_json())
 
     def as_json(self):
         class EnhancedJSONEncoder(json.JSONEncoder):
